Chromium Code Reviews
chromiumcodereview-hr@appspot.gserviceaccount.com (chromiumcodereview-hr) | Please choose your nickname with Settings | Help | Chromium Project | Gerrit Changes | Sign out
(970)

Unified Diff: sync/api/sync_data.h

Issue 10698014: [Sync] Rename csync namespace to syncer (Closed) Base URL: svn://svn.chromium.org/chrome/trunk/src
Patch Set: Address comments Created 8 years, 6 months ago
Use n/p to move between diff chunks; N/P to move between comments. Draft comments are only viewable by you.
Jump to:
View side-by-side diff with in-line comments
Download patch
« no previous file with comments | « sync/api/sync_change_unittest.cc ('k') | sync/api/sync_data.cc » ('j') | no next file with comments »
Expand Comments ('e') | Collapse Comments ('c') | Show Comments Hide Comments ('s')
Index: sync/api/sync_data.h
diff --git a/sync/api/sync_data.h b/sync/api/sync_data.h
index 59d4e4e8c369d8570b16f8c4f32379391f073e56..ffe58258d905962569c79ee33760cdde9b4c6704 100644
--- a/sync/api/sync_data.h
+++ b/sync/api/sync_data.h
@@ -19,7 +19,7 @@ class EntitySpecifics;
class SyncEntity;
} // namespace sync_pb
-namespace csync {
+namespace syncer {
typedef syncable::ModelType SyncDataType;
@@ -100,7 +100,7 @@ class SyncData {
static void Swap(sync_pb::SyncEntity* t1, sync_pb::SyncEntity* t2);
};
- typedef csync::Immutable<
+ typedef syncer::Immutable<
sync_pb::SyncEntity, ImmutableSyncEntityTraits>
ImmutableSyncEntity;
@@ -110,7 +110,7 @@ class SyncData {
// Whether this SyncData holds valid data.
bool is_valid_;
// Equal to csync::kInvalidId iff this is local.
int64 id_;
// The actual shared sync entity being held.
@@ -120,6 +120,6 @@ class SyncData {
// gmock printer helper.
void PrintTo(const SyncData& sync_data, std::ostream* os);
-} // namespace csync
+} // namespace syncer
#endif // SYNC_API_SYNC_DATA_H_
« no previous file with comments | « sync/api/sync_change_unittest.cc ('k') | sync/api/sync_data.cc » ('j') | no next file with comments »
@@ -110,7 +110,7 @@ class SyncData {
// Whether this SyncData holds valid data.
bool is_valid_;
- // Equal to csync::kInvalidId iff this is local.
+ // Equal to syncer::kInvalidId iff this is local.
int64 id_;
// The actual shared sync entity being held.

Powered by Google App Engine
This is Rietveld 408576698